pub fn unwrap_response(content: &str) -> Result<Vec<ResponsePart>>Expand description
Splits a response into parts without parsing the block contents.
Errors
See parse_response, minus the JSON failures.
pub fn unwrap_response(content: &str) -> Result<Vec<ResponsePart>>Splits a response into parts without parsing the block contents.
See parse_response, minus the JSON failures.