pub fn augment_prompt_with_errors(
prompt: &str,
errors: &[ValidationError],
) -> StringExpand description
Appends the errors from a failed attempt to the prompt for the next one.
pub fn augment_prompt_with_errors(
prompt: &str,
errors: &[ValidationError],
) -> StringAppends the errors from a failed attempt to the prompt for the next one.