pub fn build_subagent_prompt(spec: &PromptSpec<'_>) -> StringExpand description
Builds the full system prompt for the generating model.
pub fn build_subagent_prompt(spec: &PromptSpec<'_>) -> StringBuilds the full system prompt for the generating model.