pub fn next_surface_id(messages: &[HistoryMessage], base: &str) -> StringExpand description
A surface id that will not collide with anything already in history.
createSurface requires a globally unique id for the renderer’s lifetime, so
creating a second surface in the same conversation needs a fresh one.